# Activity

- psf/black repo issues and pull requests

  - Memory error #3098 [ashgrantham] R: invalid

    memory errer dectetord

    - ichard26: even-more-platforms is a branch I am working on. It is currently stalled to upstream...

  - Move imports of `ThreadPoolExecutor` into `reformat_many()`, allowing Black-in-the-browser #3046 [Zac-HD] skip news

    This is a slight perf win for use-cases that don't invoke reformat_many(), but more importantly to me today it means...

  - Black should have an opinion about doc strings #144 [Lukas0907] T: enhancement help wanted good first issue T: design

    Operating system: Ubuntu 16.04 Python version: 3.6.1 Black version: master Does also happen on master:...

    - PedanticHacker: I personally prefer this docstring format: class SimpleClass: """Create a simple class.""" ...

  - Bugs maybe #3105 [erney83] T: bug

    Describe the bug To Reproduce For example, take this code: this = "code" And run it with these arguments: $ black...

    - hauntsaninja: I can't reproduce. Could you provide more information, such as the complete output and your...

    - JelleZijlstra: This is just the template...

  - convert f-string with nothing to interpolate to regular string #1156 [raybuhr] T: enhancement F: strings / docstrings

    Is your feature request related to a problem? Please describe. f-strings are great. sometimes they are so great we...

    - dougthor42: Half the time I forget to add the f prefix. The other half the time I forget to add the curly...

  - Vim plugin fails to create virtualenv on NixOS #1767 [sbruder] T: bug C: vim

    Describe the bug When opening vim with black installed for the first time, black tries to create the virtualenv. On...

    - MatrixManAtYrService: It's not perfect, but this workaround works for me. It just ignores the extension entirely and...

    - sbruder: Thanks, that looks like a reasonable alternative. However, I have switched to formatting with...

  - DeprecationWarning: There is no current event loop #3110 [JelleZijlstra] T: bug C: maintenance

    Running Black on Python 3.11 produces: % black ast_decompiler...

    - graingert: 3.10 will also raise this warning, it might be worth running pytest with filterwarnings =...

  - Document pre-commit with --force-exclude #3109 [Ttibsi] T: documentation skip news

    Description Closes #3015 Checklist - did you ... [/] Add a CHANGELOG entry if necessary? (I don't believe this is...

    - cooperlees: Makes sense and works for me. Only enhancement I could think of is maybe showing or at least...

    - MarcoGorelli: is this the best place to put this? if you're using pre-commit, you might as well use...

      - Ttibsi: I figured it would be better to document Black's own way of doing this - we can easily add...

  - cannot import name 'ParameterSource' from 'click.core' #3111 [omonimus1] T: bug

    Installed multiple times on different project. Latest version( 22.3.0) gives the following error when...

  - Proposal: Shades of Black #3087 [JelleZijlstra] T: enhancement T: design S: needs discussion

    We often get proposals for formatting changes that could be useful, but that change the AST or are otherwise unsafe....

    - Zac-HD: I'd caution strongly against adding shades: The minimal-configuration aspect of black is very...

    - hugovk: I agree with @Zac-HD. An opt-out is still an option. There's a huge benefit to the lack of...

    - dougthor42: I'm in the "do nothing" camp. Duplicating the capabilities of isort and other tools, or even...

    - CiderMan: I also agree with @Zac-HD However, I do see value in permitting a general opt-out for AST...

    - felix-hilden: --experimental would overlap with --preview, so I'm not sure if it's worth it. The biggest point...